@@ -18,7 +18,7 @@ from .utils import *
 
 async def _get_client(ls: int, timeout: int):
     TonlibClient.enable_unaudited_binaries()
-    client = TonlibClient(ls_index=ls, default_timeout=timeout)
+    client = TonlibClient(ls_index=ls)
     await client.init_tonlib()
     return client
 
